; nSprite 2 Demos
; Last Updated: November 15th 2020
; Version: 1.2.0

; Copyright (c) 2020 Jocelyn Perreault
;
; This software is provided 'as-is', without any express or implied
; warranty. In no event will the authors be held liable for any damages
; arising from the use of this software.
;
; Permission is granted to anyone to use this software for any purpose,
; including commercial applications, and to alter it and redistribute it
; freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must not
;    claim that you wrote the original software. If you use this software
;    in a product, an acknowledgment in the product documentation would be
;    appreciated but is not required.
; 2. Altered source versions must be plainly marked as such, and must not be
;    misrepresented as being the original software.
; 3. This notice may not be removed or altered from any source distribution.

; Constants
Const scrWidth = 1280
Const scrHeight = 720
Const Version$ = "1.2.0"

; Application Init
Graphics3D scrWidth, scrHeight, 0, 2
AmbientLight 255, 255, 255
AppTitle "nSprite 2 Demos " + Version
SeedRnd MilliSecs()

; 3D Cameras
Global cam
Global camview

; nSprite 2 Init
Include "nSprite2.bb"

; FPS Data
Global FrameStart
Global DeltaTime# = 0
Global GameTime# = 0
Global FPS = 0
Global FPSCount = FPS
Global timFPS = 0

; WireFrame
Global bWireFrame = False

; Font
Global fntDefault
;Global fntDefault = nS_CreateFont("Blitz", 18, False, False, False, 255, 0, 0, 1, 0, 255)
;nS_SaveFont(fntDefault, "demos\default.fnt")

; Reset between demos
Function Reset()
	nS_ClearWorld
	cam = CreateCamera()
	camview = CreateCamera()
	nS_Initialize
	fntDefault = nS_LoadFont("demos\default.fnt")
	nS_SetFont fntDefault
	ClsColor 0, 0, 0
	CameraClsMode cam, False, False
	CameraClsMode camview, False, False
End Function

; Frame update
Function DemoBeginFrame()
	FPSCount = FPSCount + 1
	FrameStart = MilliSecs()
	If timFPS < FrameStart Then
		FPS = FPSCount
		FPSCount = 0
		timFPS = FrameStart + 1000
		DeltaTime = 1.0 / Float(FPS)
		nS_SetAnimTween DeltaTime
	End If
	GameTime = GameTime + DeltaTime
	; Wireframe mode
	If KeyHit(17) Then
		If bWireFrame Then
			bWireFrame = False
		Else
			bWireFrame = True
		End If
		WireFrame bWireFrame
	End If
	nS_Cls
End Function

; Render + flip
Function DemoEndFrame(DemoName$)
	SpriteCount = nS_SpriteCount

	nS_Text 0, 0, "FPS: " + FPS + " Dt: " + DeltaTime
	nS_Text 0, 15, "Sprites: " + SpriteCount
	nS_Text scrWidth/2, 30, DemoName, True
	nS_Text scrWidth/2, scrHeight - 20, "Press ESC to go to the next demo", True

	RenderWorld
	
	Flip False
End Function

FrameStart = MilliSecs()
timFPS = FrameStart + 1000
DeltaTime = 0.001

Reset()

Include "Demo_Features.bb"
Include "Demo_Basic.bb"
Include "Demo_Images.bb"
Include "Demo_Animation.bb"
Include "Demo_HUD.bb"
Include "Demo_Particles.bb"
Include "Demo_Lights.bb"
Include "Demo_Collisions.bb"
Include "Demo_3D.bb"
Include "Demo_Lights2.bb"
Include "Demo_GUI.bb"
Include "Demo_VoidRequiem.bb"
