; nSprite 2 Demo - Void Requiem
; Last Updated: November 15th 2020
; Version: 1.1.0

; Copyright (c) 2020 Jocelyn Perreault
;
; This software is provided 'as-is', without any express or implied
; warranty. In no event will the authors be held liable for any damages
; arising from the use of this software.
;
; Permission is granted to anyone to use this software for any purpose,
; including commercial applications, and to alter it and redistribute it
; freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must not
;    claim that you wrote the original software. If you use this software
;    in a product, an acknowledgment in the product documentation would be
;    appreciated but is not required.
; 2. Altered source versions must be plainly marked as such, and must not be
;    misrepresented as being the original software.
; 3. This notice may not be removed or altered from any source distribution.

Const scrWidth = 1920
Const scrHeight = 1080
Const Version$ = "1.1.0"
Graphics3D scrWidth, scrHeight, 0, 1
AmbientLight 255, 255, 255
AppTitle "Void Requiem " + Version
SeedRnd MilliSecs()

Include "nSprite2.bb"

Const debug = False

; Make starfield
Local camDefault = CreateCamera()
Local mdlStarfield1 = CreatePlane()
Local mdlStarfield2 = CreatePlane()
Local texStarfield1 = LoadTexture("images\starfield1.jpg")
Local texStarfield2 = LoadTexture("images\starfield2.jpg")
Local fStarfield1#, fStarfield2#
EntityTexture mdlStarfield1, texStarfield1
EntityTexture mdlStarfield2, texStarfield2
CameraProjMode camDefault, 2
MoveEntity camDefault, 0, 2, 0
TurnEntity camDefault, 90, 0, 0
CameraZoom camDefault, 2
EntityBlend mdlStarfield1, 3
EntityBlend mdlStarfield2, 3

; Init nSprite2
nS_Initialize()

; Constants & Globals

; Ships
Const SHIP_FIGHTER = 1

; Collision types
Const TYPE_SHIP = 1
Const TYPE_MISSILE = 2
Const TYPE_ASTEROID = 3

; Timing
Const DEFAULTFPS = 60
Const USEFPSDAMPING = False
Const USEFPSLIMITING = True
Const USEFIXEDUPDATE = False
Global tmrFPS = CreateTimer(DEFAULTFPS)
Global FrameStart
Global DeltaTime#
Global GameTime#
Global FPS = DEFAULTFPS
Global FPSCount = DEFAULTFPS
Global timFPS
Const FPSAVG = 4
Dim PastFPS(FPSAVG)
For i = 0 To FPSAVG
	PastFPS(i) = DEFAULTFPS
Next

; Gameplay
Global PlayerScore = 0
Global Bombs = 2
Global GameOver = False
Global MinAsteroids = 2
Global MinimumScore
Global PointsPerHit
Global PointsPerDestroy
Global Level = 0
Global NewLevel
Const RESPAWNTIME# = 2.0
Const FADETIME# = 0.3
Const MISSILEDAMAGE = 2
Const MISSILEDELAY# = 0.3
Global bWireFrame = False

; Font
;Global fntWave = nS_CreateFont("Planet Benson 2", 60, False, False, False, 255, 8, 3, -5, 32, 122)
;nS_SaveFont(fntWave, "images\wave.fnt")
;Global fntGUI = nS_CreateFont("Planet Benson 2", 30, False, False, False, 255, 32, 1, -1, 32, 122)
;nS_SaveFont(fntGUI, "images\gui.fnt")
Global fntWave = nS_LoadFont("images\wave.fnt")
Global fntGUI = nS_LoadFont("images\gui.fnt")
nS_FontColor fntWave, 60, 110, 160
nS_FontColor fntGUI, 60, 160, 110

; Global graphics
Global imgJet = nS_LoadImage("images\jet.tga", 1+2)
Global imgMissile = nS_LoadImage("images\missile.png", 1+2)
Global imgExplosion = nS_LoadAnimImage("images\explosion.png", 64, 64, 0, 16, 1+2)
Global imgAsteroid = nS_LoadImage("images\asteroid.png", 1+2)
nS_ImageBlend imgJet, 3
nS_RotateImage imgMissile, 90
nS_MidHandle imgExplosion
nS_ImageBlend imgExplosion, 3
nS_MidHandle imgAsteroid
nS_MidHandle imgMissile

; Create player
Local player.Ship = Ship_Constructor(SHIP_FIGHTER)

; Preinit some missiles, explosions and asteroids
For i = 1 To 5
	Explosion_Create(0, 0, 1, False, True)
	Missile_Launch(player, False, True)
	Asteroid_Spawn(False, True)
Next

; Game loop
While Not KeyDown(1)
	
	Gosub FPS
	
	; Update missiles
	For m.Missile = Each Missile
		Missile_Update(m)
	Next

	If Not GameOver Then
		; Update ship
		Ship_Update(player)
	End If

	; Update asteroids & spawn if needed
	If Asteroid_UpdateAll() < MinAsteroids Then
		Asteroid_Spawn()
	End If
	
	; Score & Level Update
	up = False
	Select Level
		Case 0
			up = True
			MinimumScore = 0
			PointsPerHit = 50
			PointsPerDestroy = 75
		Case 1
			If PlayerScore >= 2500 Then
				up = True
				MinimumScore = 150
				PointsPerHit = 50
				PointsPerDestroy = 100
			End If
		Case 2
			If PlayerScore >= 7500 Then
				up = True
				MinimumScore = 500
				PointsPerHit = 75
				PointsPerDestroy = 150
			End If
		Case 3
			If PlayerScore >= 15000 Then
				up = True
				MinimumScore = 1000
				PointsPerHit = 100
				PointsPerDestroy = 200
			End If
		Case 4
			If PlayerScore >= 22500 Then
				up = True
				MinimumScore = 1500
				PointsPerHit = 150
				PointsPerDestroy = 250
			End If
		Case 5
			If PlayerScore >= 30000 Then
				up = True
				MinimumScore = 2500
				PointsPerHit = 200
				PointsPerDestroy = 350
			End If
		Case 6
			If PlayerScore >= 40000 Then
				up = True
				MinimumScore = 5000
				PointsPerHit = 250
				PointsPerDestroy = 500
			End If
		Case 7
			If PlayerScore >= 50000 Then
				up = True
				MinimumScore = 7500
				PointsPerHit = 350
				PointsPerDestroy = 750
			End If
		Case 8
			If PlayerScore >= 65000 Then
				up = True
				MinimumScore = 10000
				PointsPerHit = 500
				PointsPerDestroy = 1000
			End If
		Case 9
			If PlayerScore >= 85000 Then
				up = True
				MinimumScore = 15000
				PointsPerHit = 750
				PointsPerDestroy = 1500
			End If
		Default
			If PlayerScore >= 85000 + (Level-9) * 50000 Then
				up = True
				MinimumScore = 15000 + (Level-9) * 10000
				PointsPerHit = 1000 + (Level-10) * 250
				PointsPerDestroy = PointsPerHit * 2
			End If
	End Select
	If up Then
		Bombs = Bombs + 1
		Level = Level + 1
		NewLevel = True
	End If
	
	Gosub Render

	; Pause	
	While KeyDown(29)
	Wend
	
	FPSCount = FPSCount + 1

Wend

End

.FPS
	; Timing (framerate & deltatiming)
	FrameStart = MilliSecs()
	If USEFPSLIMITING Then
		WaitTimer tmrFPS
	End If
	If timFPS < FrameStart Then
		FPS = FPSCount
		FPSCount = 0
		timFPS = FrameStart + 1000
		tFPS = 0
		For i = 0 To FPSAVG - 1
			PastFPS(i) = PastFPS(i + 1)
			tFPS = tFPS + PastFPS(i)
		Next
		PastFPS(FPSAVG) = FPS
		tFPS = tFPS + FPS
		aFPS# = (Float(tFPS) / Float(FPSAVG+1))
		If USEFPSDAMPING Then
			DeltaTime = 1.0 / aFPS
		Else
			DeltaTime = 1.0 / Float(FPS)
		End If
		If USEFIXEDUPDATE Then
			DeltaTime = 1.0 / Float(DEFAULTFPS)
		End If
		nS_SetAnimTween DeltaTime
		GameTime = GameTime + DeltaTime
	End If
Return

.Render
	; Wireframe mode
	If KeyHit(17) Then
		If bWireFrame Then
			bWireFrame = False
		Else
			bWireFrame = True
		End If
		WireFrame bWireFrame
	End If
	
	; Update starfield
	fStarfield1 = fStarfield1 - DeltaTime * 0.2 * (1 + Float(Level) / 10)
	fStarfield2 = fStarfield2 - DeltaTime * 0.1 * (1 + Float(Level) / 10)
	PositionTexture texStarfield1, fStarfield1, 0
	PositionTexture texStarfield2, fStarfield2, 0

	; Rendering
	nS_Cls()
	
	; Particles update
	nS_UpdateEmitters(DeltaTime)
	nS_UpdateParticles(DeltaTime)

	; Render elements
	For m.Missile = Each Missile
		Missile_Render(m)
	Next
	Ship_Render(player)
	Asteroid_RenderAll()
	Explosion_RenderAll()

	; Text & Gui
	If Level <> LastLevel Then
		NewWave# = -50
		nS_FontColor fntWave, 60, 110, 160, 1
		Phase = 1
		LastLevel = Level
	End If
	Select Phase
		Case 1
			nS_Text scrWidth / 2, NewWave, "Wave " + Level, True, True, fntWave
			NewWave = NewWave + 150 * DeltaTime
			If NewWave >= scrHeight / 2 Then
				Phase = 2
				NewWave = 1
			End If
		Case 2
			nS_FontColor fntWave, 60, 110, 160, NewWave
			nS_Text scrWidth / 2, scrHeight / 2, "Wave " + Level, True, True, fntWave
			NewWave = NewWave - DeltaTime
			If NewWave <= 0 Then
				Phase = 0
			End If
	End Select
	
	nS_Text 5, 5, "Health: " + player\health, False, False, fntGUI
	nS_Text 5, nS_StringHeight("Health: " + player\health, fntGUI) + 10, "Energy:", False, False, fntGUI
	nS_Text scrWidth - 5 - nS_StringWidth("Score: " + PlayerScore, fntGUI), 5, "Score: " + PlayerScore, False, False, fntGUI
	nS_Text scrWidth - 5 - nS_StringWidth("Next Wave:", fntGUI), nS_StringHeight("Score: " + PlayerScore, fntGUI) + 10, "Next Wave:", False, False, fntGUI
	nS_Text scrWidth/2, scrHeight - 5 - nS_StringHeight("Bombs: " + Bombs, fntGUI), "Bombs: " + Bombs, True, False, fntGUI
	
	; Energy Bar
	Armor# = Float(PlayerScore) / Float(MinimumScore)
	If Armor# > 1 Then
		Armor# = 1
	End If
	posx = 5
	posy = nS_StringHeight("Health: " + player\health, fntGUI) + nS_StringHeight("Energy:", fntGui) + 15
	sizex# = nS_StringWidth("Health: " + player\health, fntGui)
	sizey = 15
	nS_Color 0, 0, 0
	nS_Rect posx, posy, sizex, sizey, False, 4
	posx = posx + 2
	posy = posy + 2
	sizex = sizex - 4
	sizey = sizey - 4
	sizex = sizex * Armor
	nS_Color 60, 160, 110
	nS_Rect posx, posy, sizex, sizey
	
	; Wave Progression
	Select Level
		Case 1
			NextLevel = 2500
			PrevLevel = 0
		Case 2
			NextLevel = 7500
			PrevLevel = 2500
		Case 3
			NextLevel = 15000
			PrevLevel = 7500
		Case 4
			NextLevel = 22500
			PrevLevel = 15000
		Case 5
			NextLevel = 30000
			PrevLevel = 22500
		Case 6
			NextLevel = 40000
			PrevLevel = 30000
		Case 7
			NextLevel = 50000
			PrevLevel = 40000
		Case 8
			NextLevel = 65000
			PrevLevel = 50000
		Case 9
			NextLevel = 85000
			PrevLevel = 65000
		Default
			NextLevel = 85000 + (Level-9) * 50000
			PrevLevel = 85000 + (Level-10) * 50000
	End Select
	Wave# = Float(PlayerScore - PrevLevel) / Float(NextLevel - PrevLevel)
	posx = scrWidth - 5 - nS_StringWidth("Next Wave:", fntGUI)
	posy = nS_StringHeight("Score: " + PlayerScore, fntGUI) + nS_StringHeight("Next Wave:", fntGUI) + 15
	sizex# = nS_StringWidth("Next Wave:", fntGUI)
	sizey = 15
	nS_Color 0, 0, 0
	nS_Rect posx, posy, sizex, sizey, False, 4
	posx = posx + 2
	posy = posy + 2
	sizex = sizex - 4
	sizey = sizey - 4
	sizex = sizex * Wave
	nS_Color 60, 160, 110
	nS_Rect posx, posy, sizex, sizey
	
	; Blitz render
	RenderWorld
	
	; Buffer flip
	Flip False
	
	; Screenshot
	If KeyHit(31) Then
		imgSS = nS_CreateImage(scrWidth, scrHeight)
		nS_GrabImage imgSS, 0, 0
		nS_SaveImage imgSS, MilliSecs() + ".bmp"
	End If
	
Return

; Ship object
Type Ship
	Field img			; image
	Field x#			; x position
	Field y#			; y position
	Field typ			; type
	Field act			; activated?
	Field respawn#		; respawn time
	Field speedx#		; speed in x
	Field speedy#		; speed in y
	Field jetx[3]		; jet flames x
	Field jety[3]		; jet flames y
	Field jetflip#[3]	; flips (anim)
	Field jet[3]		; jet there
	Field jets			; number of jet
	Field dly#			; missile delay
	Field health		; health before dying
End Type

; Missiles
Type Missile
	Field img			; image
	Field x#			; x position
	Field y#			; y position
	Field act			; activated?
	Field s#			; speed
	Field b				; bomb?
End Type

; Explosions
Type Explosion
	Field img			; image
	Field x#			; x position
	Field y#			; y position
	Field act			; activated?
End Type

; Asteroids
Type Asteroid
	Field img			; image
	Field x#			; x position
	Field y#			; y position
	Field act			; activated?
	Field health		; health
	Field s#			; speed (x)
	Field ys#			; y speed
	Field rs#			; rotation speed
	Field sz#			; size
End Type

; Create a new ship
Function Ship_Constructor.Ship(id)
	Local shp.Ship = New Ship
	shp\img = nS_LoadImage("images\ship" + id + ".png", 2)
	nS_RotateImage(shp\img, 90)
	nS_MidHandle(shp\img)
	For i = 0 To 3
		shp\jet[i] = nS_CopyImage(imgJet)
	Next
	shp\typ = id
	Select id
		Case SHIP_FIGHTER
			shp\jets = 2
			shp\jetx[0] = -80
			shp\jetx[1] = -80
			shp\jety[0] = 0
			shp\jety[1] = -33
			nS_AddCollisionSphere(shp\img, 32, 36, 32, TYPE_SHIP)
	End Select
	shp\x = 150
	shp\y = scrHeight / 2
	Ship_Set(shp)
	shp\act = False
	shp\respawn = RESPAWNTIME
	Return shp
End Function

; Sets a ship
Function Ship_Set(shp.Ship)
	Select shp\typ
		Case SHIP_FIGHTER
			shp\speedx = 250
			shp\speedy = 300
			shp\health = 5
	End Select
	shp\act = True
End Function

; Render ship
Function Ship_Render(shp.Ship)
	Local alpha# = 1
	If Not shp\act Then
		If shp\respawn > FADETIME Then
			Return
		Else
			alpha = 1 - shp\respawn / FADETIME
		End If
	End If
	For i = 0 To shp\jets - 1
		shp\jetflip[i] = shp\jetflip[i] - DeltaTime
		If shp\jetFlip[i] < 0 Then
			shp\jetFlip[i] = shp\jetflip[i] + 0.01
			nS_FlipImage shp\jet[i], False, True
		End If
		nS_ImageAlpha shp\jet[i], alpha
		nS_DrawImage(shp\jet[i], shp\x + shp\jetx[i], shp\y + shp\jety[i])
	Next
	nS_ImageAlpha shp\img, alpha
	nS_DrawImage(shp\img, shp\x, shp\y)
	If debug Then
		nS_DrawCollisions(shp\img, shp\x, shp\y)
	End If
End Function

; Update ship (move)
Function Ship_Update(shp.Ship)
	Local L, R, U, D, F, B
	If shp\act Then
		shp\dly = shp\dly - DeltaTime
		If KeyDown(200) And shp\y >= 50 Then
			U = 1
		End If
		If KeyDown(208) And shp\y <= scrHeight - 50 Then
			D = 1
		End If
		If KeyDown(203) And shp\x >= 75 Then
			L = 1
		End If
		If KeyDown(205) And shp\x <= 200 Then
			R = 1
		End If
		If KeyDown(57) And shp\dly <= 0 Then
			F = 1
		End If
		If KeyDown(28) And shp\dly <= 0 And Bombs > 0 Then
			B = 1
		End If
		shp\x = shp\x + shp\speedx * (R - L) * DeltaTime
		shp\y = shp\y + shp\speedy * (D - U) * DeltaTime
		If F Then
			Missile_Launch(shp)
			shp\dly = MISSILEDELAY
		End If
		If B Then
			Missile_Launch(shp, True, False, True)
			Bombs = Bombs - 1
			shp\dly = 0.5
		End If
	Else
		shp\respawn = shp\respawn - DeltaTime
		If shp\respawn <= FADETIME Then
			For a.Asteroid = Each Asteroid
				If a\act Then
					If nS_Collided(shp\img, shp\x, shp\y, a\img, a\x, a\y) Then
						Asteroid_Damage(a, 99, 0, 0)
					End If
				End If
			Next
		End If
		If shp\respawn <= 0 Then
			PlayerScore = 0
			Ship_Set(shp)
		End If
	End If
End Function

; Damage ship
Function Ship_Damage(shp.Ship, dmg)
	shp\health = shp\health - dmg
	If shp\health <= 0 Then
		Explosion_Create(shp\x, shp\y, 1.5)
		For i = 1 To 5
			Explosion_Create(shp\x + Rnd(0, 30) - 15, shp\y + Rnd(0, 30) - 15, Rnd(0.5, 0.7))
		Next
		shp\act = False
		shp\respawn = RESPAWNTIME
		If PlayerScore <= MinimumScore Then
			GameOver = True
		End If
	End If
End Function

; Launch a new missile
Function Missile_Launch(shp.Ship, activate = True, forcenew = False, bomb = False)
	Local m.Missile
	f = False
	If Not forcenew Then
		For m = Each Missile
			If Not m\act Then
				f = True
				Exit
			End If
		Next
	End If
	If Not f Then
		m = New Missile
		m\img = nS_CopyImage(imgMissile)
		nS_AddCollisionPolyPoint(m\img, 0, 60, TYPE_MISSILE)
		nS_AddCollisionPolyPoint(m\img, 8, 0, TYPE_MISSILE)
		nS_AddCollisionPolyPoint(m\img, 16, 60, TYPE_MISSILE)
	End If
	If bomb Then
		m\s = 350
		m\b = True
		nS_ScaleImage m\img, 1.3, 1.0, True
		nS_ImageColor m\img, 255, 255, 0
	Else
		m\s = 550
		m\b = False
		nS_ScaleImage m\img, 0.6, 0.6, True
		nS_ImageColor m\img, 255, 255, 255
	End If
	m\x = shp\x
	m\y = shp\y
	m\act = activate
End Function

; Update missile & collisions
Function Missile_Update(m.Missile)
	Local d#, dx, dy
	If m\act Then
		m\x = m\x + m\s * DeltaTime
		For a.Asteroid = Each Asteroid
			If a\act Then
				If nS_Collided(m\img, m\x, m\y, a\img, a\x, a\y) Then
					m\act = False
					PlayerScore = PlayerScore + PointsPerHit
					If m\b Then
						Explosion_Create(m\x, m\y, 3.6)
						Asteroid_Damage(a, 99, m\x, m\y, True)
					Else
						Explosion_Create(m\x, m\y, 0.6)
						Asteroid_Damage(a, MISSILEDAMAGE, m\x, m\y, True)
					End If
				End If
			End If
		Next
		If m\x >= scrWidth Then
			m\act = False
		End If
	End If
End Function

; Render missile
Function Missile_Render(m.Missile)
	If m\act Then
		nS_DrawImage(m\img, m\x, m\y)
		If debug Then
			nS_DrawCollisions(m\img, m\x, m\y)
		End If
	End If
End Function

; Create a new explosion
Function Explosion_Create(x, y, r# = 1, activate = True, forcenew = False)
	Local e.Explosion
	f = False
	If x > scrWidth + nS_ImageWidth(imgExplosion) / 2 Then
		Return
	End If
	If Not forcenew Then
		For e = Each Explosion
			If Not e\act Then
				f = True
				Exit
			End If
		Next
	End If
	If Not f Then
		e = New Explosion
		e\img = nS_CopyImage(imgExplosion)
	End If
	e\act = activate
	If activate Then
		e\x = x
		e\y = y
		nS_ScaleImage e\img, r, r, True
		nS_AnimateImage e\img, nS_ANIM_ONESHOT, 50, 0, 15
		nS_RotateImage e\img, Rnd(0, 360)
	End If
End Function

; Render all explosions
Function Explosion_RenderAll()
	For e.Explosion = Each Explosion
		If e\act Then
			nS_DrawImage e\img, e\x, e\y
			If Not nS_IsAnimImagePlaying(e\img) Then
				e\act = False
			End If
		End If
	Next
End Function

; Spawn a new asteroid
Function Asteroid_Spawn(activate = True, forcenew = False, x = -1, y = -1, sz# = -1, sx# = -1, sy# = -1)
	Local a.Asteroid
	f = False
	If Not forcenew Then
		For a = Each Asteroid
			If Not a\act Then
				f = True
				Exit
			End If
		Next
	End If
	If Not f Then
		a = New Asteroid
		a\img = nS_CopyImage(imgAsteroid)
	End If	
	nS_FreeCollisions(a\img)
	If x = -1 Then
		a\x = scrWidth + nS_ImageWidth(imgAsteroid) / 2 + Rand(0, nS_ImageWidth(a\img) * 5)
		a\y = Rand(0, scrHeight)
		sz# = Rnd(0.2, 0.6) + Float(Level) * 0.025
		a\s = Rand(50, 150) + Level * 20
		a\ys = 0
	Else
		a\x = x
		a\y = y
		a\s = sx
		a\ys = sy
	End If
	a\health = sz * 17
	a\sz = sz
	nS_ScaleImage(a\img, sz, sz, True)
	nS_AddCollisionSphere(a\img, nS_ImageWidth(imgAsteroid)/2, nS_ImageWidth(imgAsteroid)/2, nS_ImageWidth(imgAsteroid)/2, TYPE_ASTEROID)
	a\rs = Rand(0, 30) - 15
	a\act = activate
End Function

; Update all asteroids
Function Asteroid_UpdateAll#()
	Local c# = 0
	For a.Asteroid = Each Asteroid 
		If a\act Then
			a\s = a\s + 15 * DeltaTime
			a\x = a\x - a\s * DeltaTime
			a\y = a\y - a\ys * DeltaTime
			nS_RotateImage a\img, a\rs * DeltaTime
			If a\x < nS_ImageWidth(imgAsteroid) / -2 Then
				a\act = False
			Else
				c = c + a\sz
			End If
			If a\act Then
				For as.Asteroid = Each Asteroid
					If as\act And as <> a Then
						If nS_Collided(as\img, as\x, as\y, a\img, a\x, a\y) Then
							Asteroid_Damage(a, 1, as\x, as\y)
							Asteroid_Damage(as, 0, a\x, a\y)
						End If
					End If
				Next
			End If
			For shp.Ship = Each Ship
				If shp\act Then
					If nS_Collided(shp\img, shp\x, shp\y, a\img, a\x, a\y) Then
						Ship_Damage(shp, a\sz * 5)
						Asteroid_Damage(a, 99, 0, 0)
					End If
				End If
			Next
		End If
	Next
	Return c
End Function

; Render all asteroids
Function Asteroid_RenderAll()
	For a.Asteroid = Each Asteroid 
		If a\act Then
			nS_DrawImage a\img, a\x, a\y
			If debug Then
				nS_DrawCollisions(a\img, a\x, a\y)
			End If
		End If
	Next
End Function

; Give damage to asteroid
Function Asteroid_Damage(a.Asteroid, dmg = 1, x# = 0, y# = 0, m = False)
	a\health = a\health - dmg
	x = a\x - x
	y = a\y - y
	a\s = a\s - 0.1 * x
	a\ys = a\ys - 0.15 * y
	a\rs = a\rs + 0.1 * y
	If a\health <= 0 Then
		a\act = False
		If m Then
			PlayerScore = PlayerScore + PointsPerDestroy
		End If
		Explosion_Create(a\x, a\y, a\sz * 5)
		If a\sz > 0.3 And dmg < 50 Then
			Asteroid_Spawn(True, False, Rand(a\x - nS_ImageWidth(a\img)/2, a\x + nS_ImageWidth(a\img)/2), Rand(a\y - nS_ImageHeight(a\img)/2, a\y + nS_ImageHeight(a\img)/2), a\sz*0.6, Rand(0, 200) - 100, Rand(0, 50) - 25)
			Asteroid_Spawn(True, False, Rand(a\x - nS_ImageWidth(a\img)/2, a\x + nS_ImageWidth(a\img)/2), Rand(a\y - nS_ImageHeight(a\img)/2, a\y + nS_ImageHeight(a\img)/2), a\sz*0.6, Rand(0, 200) - 100, Rand(0, 50) - 25)
			Asteroid_Spawn(True, False, Rand(a\x - nS_ImageWidth(a\img)/2, a\x + nS_ImageWidth(a\img)/2), Rand(a\y - nS_ImageHeight(a\img)/2, a\y + nS_ImageHeight(a\img)/2), a\sz*0.6, Rand(0, 200) - 100, Rand(0, 50) - 25)
		End If
	End If
End Function